@@ -86,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -133,6 +133,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -198,7 +204,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -208,7 +214,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56100
 #  endif
 #endif
 
@@ -245,6 +251,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
